@@ -4,14 +4,16 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Exporter 'import';
 
-our @EXPORT    = qw/return_modifiers/;
-our @EXPORT_OK = qw/return_modifiers return_has return_with return_around return_extends return_before return_after/;
+our @EXPORT = qw/return_modifiers/;
+our @EXPORT_OK =
+  qw/return_modifiers return_has return_with return_around return_extends return_before return_after/;
 
-our $moo_modifiers; BEGIN { $moo_modifiers = [qw/has with around extends before after/] };
+our $moo_modifiers;
+BEGIN { $moo_modifiers = [qw/has with around extends before after/] }
 
 sub return_modifiers {
     my %modifiers = ();
@@ -25,27 +27,33 @@ sub return_modifiers {
 }
 
 sub return_has {
- 	return_modifiers($_[0], [qw/has/], 1)->{has};
+    my %mod = return_modifiers( $_[0], [qw/has/] );
+    return $mod{has};
 }
 
 sub return_with {
-	return_modifiers($_[0], [qw/with/], 1)->{with};
+    my %mod = return_modifiers( $_[0], [qw/with/] );
+    return $mod{with};
 }
 
 sub return_around {
-	return_modifiers($_[0], [qw/around/], 1)->{around};
+    my %mod = return_modifiers( $_[0], [qw/around/] );
+    return $mod{around};
 }
 
 sub return_extends {
-    	return_modifiers($_[0], [qw/extends/], 1)->{extends};
+    my %mod = return_modifiers( $_[0], [qw/extends/] );
+    return $mod{extends};
 }
 
 sub return_before {
-    	return_modifiers($_[0], [qw/before/], 1)->{before};
+    my %mod = return_modifiers( $_[0], [qw/before/] );
+    return $mod{before};
 }
 
 sub return_after {
-    	return_modifiers($_[0], [qw/after/], 1)->{after};
+    my %mod = return_modifiers( $_[0], [qw/after/] );
+    return $mod{after};
 }
 
 =head1 NAME
@@ -54,7 +62,7 @@ MooX::ReturnModifiers - Returns Moo Modifiers as a Hash
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
